@@ -1,5 +1,6 @@
 package Net::Kubernetes;
-$Net::Kubernetes::VERSION = '0.10';
+# ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
+$Net::Kubernetes::VERSION = '0.11';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -9,25 +10,61 @@ require Throwable::Error;
 use MIME::Base64;
 require Net::Kubernetes::Exception;
 
-# ABSTRACT: Perl interface to kubernetes
+
+
+with 'Net::Kubernetes::Role::APIAccess';
+with 'Net::Kubernetes::Role::ResourceLister';
+
+
+
+has 'default_namespace' => (
+	is         => 'rw',
+	isa        => 'Net::Kubernetes::Namespace',
+	required   => 0,
+	lazy       => 1,
+	handles    => [qw(get_pod get_rc get_replication_controller get_secret get_service create create_from_file build_secret)],
+	builder    => '_get_default_namespace',
+);
+
+sub get_namespace {
+	my($self, $namespace) = @_;
+	if (! defined $namespace || ! length $namespace) {
+		Throwable::Error->throw(message=>'$namespace cannot be null');
+	}
+	my $res = $self->ua->request($self->create_request(GET => $self->path.'/namespaces/'.$namespace));
+	if ($res->is_success) {
+		my $ns = $self->json->decode($res->content);
+		my(%create_args) = (url => $self->url, base_path=>$ns->{metadata}{selfLink}, namespace=> $namespace, _namespace_data=>$ns);
+		$create_args{username} = $self->username if(defined $self->username);
+		$create_args{password} = $self->password if(defined $self->password);
+		return Net::Kubernetes::Namespace->new(%create_args);
+	}else{
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error getting namespace $namespace:\n".$res->message);
+	}
+}
+
+sub _get_default_namespace {
+	my($self) = @_;
+	return $self->get_namespace('default');
+}
+
+# SEEALSO: Net::Kubernetes::Namespace, Net::Kubernetes::Resource
+
+return 42;
+
+__END__
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Net::Kubernetes
+Net::Kubernetes - An object oriented interface to the REST API's provided by kubernetes
 
 =head1 VERSION
 
-version 0.10
-
-This package provides an object oriented interface to the REST API's provided by kubernetes.
-
-=head1 STATUS
-
-=begin html
-
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=master" />
-
-=end html
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -46,28 +83,9 @@ This package provides an object oriented interface to the REST API's provided by
   
   my $other_pod = $ns->create_from_file('./my-pod.yaml');
 
-=head1 Description
+=head1 METHODS
 
-This package allows programatic access to the L<Kubernetes|http://kubernetes.io> rest api.
-
-Please note this package is still a BETA release (as is kubernetes itself), and the methods
-and API are still subject to change.  Use at your own risk.
-
-=cut
-
-
-with 'Net::Kubernetes::Role::APIAccess';
-with 'Net::Kubernetes::Role::ResourceLister';
-with 'Net::Kubernetes::Role::ResourceCreator';
-
-=head1 Methods
-
-By convention, methods will throw exceptions if kubernetes api server returns a non-successful status code.
-Unless otherwise noted, assume this behavoir through out.
-
-=over 1
-
-=item new - Create a new $kube object
+=head2 new - Create a new $kube object
 
 All parameters are optional and have some basic default values (where appropriate).
 
@@ -99,93 +117,73 @@ to a file handle (from which to read the token).
 
 =back
 
-=item $kube->get_namespace("myNamespace");
+=head2 get_namespace("myNamespace");
 
 This method returns a "Namespace" object on which many methods can be called implicitly
 limited to the specified namespace.
 
-=item my(@pods) = $kube->list_pods([label=>{label=>value}], [fields=>{field=>value}])
+=head2 get_pod('my-pod-name')
 
-=item my(@rcs) = $kube->list_rc([label=>{label=>value}], [fields=>{field=>value}])
+Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespace('default')
 
-=item my(@rcs) = $kube->list_replication_controllers([label=>{label=>value}], [fields=>{field=>value}]) (alias to list_rc)
+=head2 get_repllcation_controller('my-rc-name') (aliased as $ns->get_rc('my-rc-name'))
 
-=item my(@scerets) = $kube->list_secrets([label=>{label=>value}], [fields=>{field=>value}])
+Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespace('default')
 
-=item my(@services) = $kube->list_services([label=>{label=>value}], [fields=>{field=>value}])
+=head2 get_service('my-servce-name')
 
-=item my $resource = $kube->create({OBJECT})
+Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespace('default')
 
-=item my $resource = $kube->create_from_file(PATH_TO_FILE) (accepts either JSON or YAML files)
+=head2 get_secret('my-secret-name')
+
+Delegates automatically to L<Net::Kubernetes::Namespace> via $self->get_namespace('default')
+
+=begin html
+
+<h2>Build Status</h2>
+
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.10" />
+
+=end html
+
+=head1 AUTHOR
+
+Dave Mueller <dave@perljedi.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Dave Mueller.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Net::Kubernetes::Namespace|Net::Kubernetes::Namespace>
+
+=item *
+
+L<Net::Kubernetes::Resource|Net::Kubernetes::Resource>
 
 =back
 
-=head2 The following methods are automatically deligated to the 'default' namespace.
+=head1 CONSUMES
 
-=over 1
+=over 4
 
-=item $ns->get_pod('my-pod-name')
+=item * L<Net::Kubernetes::Role::APIAccess>
 
-=item $ns->get_repllcation_controller('my-rc-name') (aliased as $ns->get_rc('my-rc-name'))
+=item * L<Net::Kubernetes::Role::ResourceFactory>
 
-=item $ns->get_service('my-servce-name')
-
-=item $ns->get_secret('my-secret-name')
-
-
-Create from file is really just a short cut around something like:
-
-  my $object = YAML::LoadFile(PATH_TO_FILE);
-  $kube->create($object);
+=item * L<Net::Kubernetes::Role::ResourceLister>
 
 =back
 
 =cut
-
-has 'default_namespace' => (
-	is         => 'rw',
-	isa        => 'Net::Kubernetes::Namespace',
-	required   => 0,
-	lazy       => 1,
-	handles    => [qw(get_pod get_rc get_replication_controller get_secret get_service)],
-	builder    => '_get_default_namespace',
-);
-
-sub get_namespace {
-	my($self, $namespace) = @_;
-	if (! defined $namespace || ! length $namespace) {
-		Throwable::Error->throw(message=>'$namespace cannot be null');
-	}
-	my $res = $self->ua->request($self->create_request(GET => $self->path.'/namespaces/'.$namespace));
-	if ($res->is_success) {
-		my $ns = $self->json->decode($res->content);
-		my(%create_args) = (url => $self->url, base_path=>$ns->{metadata}{selfLink}, namespace=> $namespace, _namespace_data=>$ns);
-		$create_args{username} = $self->username if(defined $self->username);
-		$create_args{password} = $self->password if(defined $self->password);
-		return Net::Kubernetes::Namespace->new(%create_args);
-	}else{
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error getting namespace $namespace:\n".$res->message);
-	}
-}
-
-sub _get_default_namespace {
-	my($self) = @_;
-	return $self->get_namespace('default');
-}
-
-return 42;
-
-=head1 See Also
-
-L<Net::Kubernetes::Namespace>, L<Net::Kubernetes::Resource>
-
-=head1 AUTHOR
-
-  Dave Mueller <dave@perljedi.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Dave Mueller.
-
-This is free software; you can redistribute it and/or modify it under the
-same terms as the Perl 5 programming language system itself.
