@@ -1,20 +1,9 @@
 package Net::Kubernetes::Namespace;
-$Net::Kubernetes::Namespace::VERSION = '0.10';
+# ABSTRACT: Provides access to kubernetes respources within a single namespace.
+$Net::Kubernetes::Namespace::VERSION = '0.11';
 use Moose;
 use MooseX::Aliases;
-
-=head1 NAME
-
-Net::Kubernetes::Namespace
-
-=head1 VERSION
-
-version 0.10
-
-Provides access to kubernetes respources within a single namespace.
-
-=cut
-
+use syntax 'try';
 
 has namespace => (
 	is       => 'ro',
@@ -34,36 +23,6 @@ with 'Net::Kubernetes::Role::ResourceCreator';
 with 'Net::Kubernetes::Role::ResourceFactory';
 
 
-=head1 Methods
-
-=over 1
-
-=item $ns->list_pods([label=>{label=>value}], [fields=>{field=>value}])
-
-=item $ns->list_rc([label=>{label=>value}], [fields=>{field=>value}])
-
-=item $ns->list_replication_controllers([label=>{label=>value}], [fields=>{field=>value}]) (alias to list_rc)
-
-=item $ns->list_secrets([label=>{label=>value}], [fields=>{field=>value}])
-
-=item $ns->list_services([label=>{label=>value}], [fields=>{field=>value}])
-
-=item my $resource = $ns->create({OBJECT})
-
-=item my $resource = $ns->create_from_file(PATH_TO_FILE) (accepts either JSON or YAML files)
-
-=item $ns->get_pod('my-pod-name')
-
-=item $ns->get_repllcation_controller('my-rc-name') (aliased as $ns->get_rc('my-rc-name'))
-
-=item $ns->get_service('my-servce-name')
-
-=item $ns->get_secret('my-secret-name')
-
-=back
-
-=cut
-
 sub get_secret {
 	my($self, $name) = @_;
 	Net::Kubernetes::Exception->throw(message=>"Missing required parameter 'name'") if(! defined $name || ! length $name);
@@ -97,6 +56,78 @@ sub get_resource_by_name {
 		return $self->create_resource_object($self->json->decode($res->content));
 	}
 	else {
-		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$res->message);
+		my $message;
+		try{
+			my $obj = $self->json->decode($res->content);
+			$message = $obj->{message};
+		}
+		catch($e) {
+			$message = $res->message;
+		}
+		Net::Kubernetes::Exception->throw(code=>$res->code, message=>$message);
 	}
 }
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Kubernetes::Namespace - Provides access to kubernetes respources within a single namespace.
+
+=head1 VERSION
+
+version 0.11
+
+=head1 METHODS
+
+=head2 $ns->get_pod('my-pod-name')
+
+=head2 $ns->get_repllcation_controller('my-rc-name') (aliased as $ns->get_rc('my-rc-name'))
+
+=head2 $ns->get_service('my-servce-name')
+
+=head2 $ns->get_secret('my-secret-name')
+
+=head1 AUTHOR
+
+Dave Mueller <dave@perljedi.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Dave Mueller.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Net::Kubernetes|Net::Kubernetes>
+
+=back
+
+=head1 CONSUMES
+
+=over 4
+
+=item * L<Net::Kubernetes::Role::APIAccess>
+
+=item * L<Net::Kubernetes::Role::ResourceCreator>
+
+=item * L<Net::Kubernetes::Role::ResourceFactory>
+
+=item * L<Net::Kubernetes::Role::ResourceLister>
+
+=back
+
+=cut
