@@ -1,21 +1,11 @@
 package Net::Kubernetes::Resource::Role::HasPods;
-$Net::Kubernetes::Resource::Role::HasPods::VERSION = '0.10';
+# ABSTRACT: Resource role for types that may contain pods
+$Net::Kubernetes::Resource::Role::HasPods::VERSION = '0.11';
 use Moose::Role;
 
-=head1 NAME
-
-Net::Kubernetes::Resource::Role::HasPods
-
-=head1 VERSION
-
-version 0.10
-
-Role for resource object which might "Have Pods" ... i.e. Replication Controller or Services
-
-=cut
-
 with 'Net::Kubernetes::Role::APIAccess';
 
+
 sub get_pods {
 	my($self) = @_;
 	my $uri = URI->new_abs("../pods", $self->path);
@@ -50,3 +40,57 @@ sub _build_selector_from_hash {
 }
 
 return 42;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Kubernetes::Resource::Role::HasPods - Resource role for types that may contain pods
+
+=head1 VERSION
+
+version 0.11
+
+=head1 METHODS
+
+=head2 get_pods
+
+retreive a list of pods associated with with respource (either ReplicationController or Service)
+
+=head1 AUTHOR
+
+Dave Mueller <dave@perljedi.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Dave Mueller.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Net::Kubernetes|Net::Kubernetes>
+
+=back
+
+=head1 CONSUMES
+
+=over 4
+
+=item * L<Net::Kubernetes::Role::APIAccess>
+
+=back
+
+=cut
