@@ -1,5 +1,6 @@
 package Net::Kubernetes::Role::ResourceFactory;
-$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.10';
+# ABSTRACT: Role to allow easy construction of Net::Kubernetes::Resouce::* objects
+$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.11';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
@@ -7,16 +8,6 @@ require Net::Kubernetes::Resource::Pod;
 require Net::Kubernetes::Resource::ReplicationController;
 require Net::Kubernetes::Resource::Secret;
 
-=head1 NAME
-
-Net::Kubernetes::Role::ResourceFactory
-
-=head1 VERSION
-
-version 0.10
-
-=cut
-
 sub create_resource_object {
 	my($self, $object, $kind) = @_;
 	$kind ||= $object->{kind};
@@ -32,3 +23,43 @@ sub create_resource_object {
 
 
 return 42;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Kubernetes::Role::ResourceFactory - Role to allow easy construction of Net::Kubernetes::Resouce::* objects
+
+=head1 VERSION
+
+version 0.11
+
+=head1 AUTHOR
+
+Dave Mueller <dave@perljedi.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Dave Mueller.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Net::Kubernetes|Net::Kubernetes>
+
+=back
+
+=cut
