@@ -1,21 +1,12 @@
 package Net::Kubernetes::Role::ResourceLister;
-$Net::Kubernetes::Role::ResourceLister::VERSION = '0.10';
+# ABSTRACT: Role to give access to list_* methods.
+$Net::Kubernetes::Role::ResourceLister::VERSION = '0.11';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Service;
 require Net::Kubernetes::Resource::Pod;
 require Net::Kubernetes::Resource::ReplicationController;
 
-=head1 NAME
-
-Net::Kubernetes::Role::ResourceLister
-
-=head1 VERSION
-
-version 0.10
-
-=cut
-
 with 'Net::Kubernetes::Role::ResourceFactory';
 
 requires 'ua';
@@ -52,6 +43,7 @@ sub list_pods {
 	}
 }
 
+
 sub list_replication_controllers {
 	my $self = shift;
 	my(%options);
@@ -83,6 +75,7 @@ sub list_replication_controllers {
 
 alias list_rc => 'list_replication_controllers';
 
+
 sub list_services {
 	my $self = shift;
 	my(%options);
@@ -112,6 +105,8 @@ sub list_services {
 	}
 }
 
+
+
 sub list_secrets {
 	my $self = shift;
 	my(%options);
@@ -151,3 +146,73 @@ sub _build_selector_from_hash {
 }
 
 return 42;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Kubernetes::Role::ResourceLister - Role to give access to list_* methods.
+
+=head1 VERSION
+
+version 0.11
+
+=head1 METHODS
+
+=head2 list_pods([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Pod>s
+
+=head2 list_rc([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::ReplicationController>s
+
+=head2 list_replication_controllers([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::ReplicationController>s
+
+=head2 list_services([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Service>s
+
+=head2 list_secrets([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Secret>s
+
+=head1 AUTHOR
+
+Dave Mueller <dave@perljedi.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2015 by Dave Mueller.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 SEE ALSO
+
+Please see those modules/websites for more information related to this module.
+
+=over 4
+
+=item *
+
+L<Net::Kubernetes|Net::Kubernetes>
+
+=back
+
+=head1 CONSUMES
+
+=over 4
+
+=item * L<Net::Kubernetes::Role::ResourceFactory>
+
+=back
+
+=cut
